@@ -1,5 +1,11 @@
 var NAVTREEINDEX18 =
 {
+"structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f":[10,7,4,8,0],
+"structpw__client__session__events.html#a8e823bcde1844c0857314b10069f3b8d":[10,7,4,8,1],
+"structpw__client__session__events.html#aae0dc344c9b1d62b21fb16e4fc2c9c33":[10,7,4,8,3],
+"structpw__client__session__events.html#af3eab807465363845550f89f1bb9d816":[10,7,4,8,2],
+"structpw__client__session__methods.html":[10,7,4,9],
+"structpw__client__session__methods.html#a4537bb47cfe11b27649ffe082fdd49fa":[10,7,4,9,0],
 "structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a":[10,7,4,9,1],
 "structpw__context.html":[10,4,2,3],
 "structpw__context__events.html":[10,4,2,1],
@@ -243,11 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e":[10,5,7,1,14],
 "structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12":[10,5,7,1,11],
 "structpw__impl__port.html":[10,5,4,3],
-"structpw__impl__port.html":[10,5,8,2],
-"structpw__impl__port.html":[10,5,7,3],
-"structpw__impl__port__events.html":[10,5,8,1],
-"structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[10,5,8,1,8],
-"structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325":[10,5,8,1,1],
-"structpw__impl__port__events.html#a69e18fd1facb78dbb42025c17ef0884a":[10,5,8,1,4],
-"structpw__impl__port__events.html#a7049ef85f5a0f35988c6a2f60a02c385":[10,5,8,1,2]
+"structpw__impl__port.html":[10,5,8,2]
 };
